#!/bin/csh -f
#
# build-samples.csh: build the S2PLOT sample FORTRAN and C programs
#
# David Barnes, November 2005
#
# $Id: build-samples.csh,v 3.14 2007/04/04 23:07:40 dbarnes Exp $

if (!(${?S2PATH})) then
  echo "S2PATH environment variable MUST be set ... please fix and retry."
  exit(-1);
endif
if (! -d $S2PATH || ! -e ${S2PATH}/s2plot.csh) then
  echo "S2PATH is set but invalid: ${S2PATH} ... please fix and retry."
  exit(-1);
endif
source ${S2PATH}/s2plot.csh
if ($status) then
  exit(-1)
endif

set thisdir=$cwd
if ($thisdir != $S2PATH) then
  echo "You must be in directory ${S2PATH} to run build-samples.csh script."
  echo "(or if you are, try removing any trailing '/' in your S2PATH setting)"
  exit(-1);
endif

if ($S2SHARED == yes) then
  echo "Using shared S2PLOT library for ${S2KERNEL}."
else
  echo "Using static S2PLOT library for ${S2KERNEL}."
endif

if (! -d $S2KERNEL) then
  echo "Directory ${S2KERNEL} does not exist!  Cannot build!  Try running"
  echo "build-lib.csh script first, or re-installing your distribution."
  exit(-1);
endif

if (! -e ${S2KERNEL}/${S2LIBNAME}) then
  echo "Library ${S2LIBNAME} is missing!  Cannot build!  Try running "
  echo "build-lib.csh script first, or re-installing your distribution."
  exit(-1);
endif

echo "Entering target directory ${S2KERNEL}."
cd $S2KERNEL

set S2OBJECTS=""

foreach target (s2uc1 s2uc2 s2uc3 s2uc4 s2uc5 s2uc6 s2uc7 s2uc8 s2uc9 s2uc10 s2uc11 s2uc12 volrender isosurf)
  echo "Compiling sample program ($target) ..."
  $S2COMPILER ../samples/${target}.c
  set S2OBJECTS="${S2OBJECTS} ${target}.o"
  echo "Linking sample program (${target}) ..."
if ($S2OSTYPE != cygwin) then
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} -L${S2X11PATH}/lib -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}
else
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} ${IMATH} -lm
endif
  if ($S2KERNEL == darwin && $S2SHARED == yes) then
    echo "Modifying dynamic library path ..."
    install_name_tool -change ${S2PATH}/${S2KERNEL}/${S2LIBNAME} @executable_path/${S2LIBNAME} ${target}
  endif
end

foreach target (fs2uc1 fs2uc2 fs2uc3 fs2uc4 fs2uc5 fs2uc6 fs2uc7 fs2uc8 fs2uc9 fs2uc10 fs2uc11 fs2uc12)
  echo "Compiling FORTRAN sample program (${target}) ..."
  $S2FOMPILER -I../samples ../samples/${target}.${fext}
  set TMPOBJ=${target}.o
  if (-e ../samples/${target}extern.${fext}) then
    $S2FOMPILER -I../samples ../samples/${target}extern.${fext}
    set TMPOBJ="${TMPOBJ} ${target}extern.o"
    if (-e ../samples/${target}extern2.${fext}) then
      $S2FOMPILER -I../samples ../samples/${target}extern2.${fext}
      set TMPOBJ="${TMPOBJ} ${target}extern2.o"
    endif
  endif
  echo "Linking FORTRAN sample program (${target}) ..."
if ($S2OSTYPE != cygwin) then
  $S2FLINKER -o ${target} ${TMPOBJ} -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}
else
  $S2FLINKER -o ${target} ${TMPOBJ} -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} ${IMATH} -lm 
endif
  set S2OBJECTS="${S2OBJECTS} ${TMPOBJ}"
  if ($S2KERNEL == darwin && $S2SHARED == yes) then
    echo "Modifying dynamic library path ..."
    install_name_tool -change ${S2PATH}/${S2KERNEL}/${S2LIBNAME} @executable_path/${S2LIBNAME} ${target}
  endif
end

# astro* are targets that are self-contained astro examples
foreach target (astro1 astro1a)
  echo "Compiling sample program ($target) ..."
  $S2COMPILER ../samples/${target}.c
  set S2OBJECTS="${S2OBJECTS} ${target}.o"
  echo "Linking sample program (${target}) ..."
if ($S2OSTYPE != cygwin) then
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}
else
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} ${IMATH} -lm
endif
  if ($S2KERNEL == darwin && $S2SHARED == yes) then
    echo "Modifying dynamic library path ..."
    install_name_tool -change ${S2PATH}/${S2KERNEL}/${S2LIBNAME} @executable_path/${S2LIBNAME} ${target}
  endif
end

echo Removing objects ...
rm -rf $S2OBJECTS

echo Done!

exit

# xastro* are targets that are astro examples using libstevemoshier and libcoco
if ((${?SMCOCO_INC}) && (${?SMCOCO_LIB})) then
if (${?PGDPATH}) then
  set SMCOCO_INC="-I${PGDPATH}/stevemoshier"
  set SMCOCO_LIB="-L${PGDPATH}/${S2KERNEL} -lcoco -lstevemoshier"
  foreach target (xastro1)
    echo "Compiling sample program ($target) ..."
    $S2COMPILER ${SMCOCO_INC} ../samples/${target}.c
    set S2OBJECTS="${S2OBJECTS} ${target}.o"
    echo "Linking sample program (${target}) ..."
    $S2CLINKER -o ${target} ${target}.o ${SMCOCO_LIB} -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}
    if ($S2KERNEL == darwin && $S2SHARED == yes) then
      echo "Modifying dynamic library path ..."
      install_name_tool -change ${S2PATH}/${S2KERNEL}/${S2LIBNAME} @executable_path/${S2LIBNAME} ${target}
    endif
  end
endif
endif

