c fs2uc5.f: demonstration / use case 5 for S2PLOT library.
c
c David Barnes, November 2005
c
c $Id: fs2uc5.f,v 3.1.1.1 2006/12/22 03:33:25 dbarnes Exp $
c
c Demonstrates the "native" S2PLOT functions.  These functions are
c the most directly related to the GEOM format description by Paul
c Bourke and supported by the stereo2 and geomviewer programs.
c The general use of these functions is to use textures, and/or to 
c use some internal features such as colour blending along lines 
c and on faces.
c
      REAL XLIMIT, YLIMIT, ZLIMIT, TWOPI
c
      PARAMETER (XLIMIT=10.0, YLIMIT=10.0, ZLIMIT=10.0)
      PARAMETER (TWOPI=6.2831853)
c
c     Some useful variables
      REAL X1, X2, Y1, Y2, Z1, Z2
      REAL*8 PXYZ(3)
      REAL*8 NXYZ(3)
      REAL*8 RT(3), UP(3)
      REAL*8 P1(3), P2(3)
      REAL*8 COLOUR(3), COL1(3), COL2(3)
      REAL*8 PF3(3,3)
      REAL*8 PF4(3,4)
      REAL*8 COLS(3,3), NORMS(3,3), COL4(3,4), NORM4(3,4)
c     
c     Set the bounds we will use in S2PLOT
      X1 = -XLIMIT
      X2 =  XLIMIT
      Y1 = -YLIMIT
      Y2 =  YLIMIT
      Z1 = -ZLIMIT
      Z2 =  ZLIMIT
c     
c     Open the S2PLOT device, in mono and non-fullscreen mode
      call s2opend('/?')
c     
c     Set the S2PLOT world coordinate range
      call s2swin(X1, X2, Y1, Y2, Z1, Z2)
c     
c     Draw and label a box around the points in white colour
      call s2sci(1)
      call s2sch(1.2)
      call s2slw(1.0)
      call s2box('BCDETS', 0., 0, 'BCDETS', 0., 0, 'BCDETS', 0., 0)
c     
c     native spheres
      call ns2sphere(-2., 2., 2., 0.5, 0.6, 0.6, 0.9)
      PXYZ(1) = -4.
      PXYZ(2) = 2.
      PXYZ(3) = 2.
      COLOUR(1) = 0.9
      COLOUR(2) = 0.6
      COLOUR(3) = 0.6
      call ns2vsphere(PXYZ, 0.75, COLOUR)
c
c     native textured spheres
      call ns2spheret(2., -2.,  2., 0.5, 0.6, 0.6, 0.9, 
     +    'firetile2_pow2_rgb.tga')
      PXYZ(1) = 2.
      PXYZ(2) = -4.
      PXYZ(3) = 2.
      COLOUR(1) = 0.9
      COLOUR(2) = 0.6
      COLOUR(3) = 0.6
      call ns2vspheret(PXYZ, 0.75, COLOUR, 'firetile2_pow2_rgb.tga')
c
c     native disks
      call ns2disk(2., 2., 2., -1., -1., -1., 1., 2., 0.8, 0.4, 0.2)
      PXYZ(1) = 2.
      PXYZ(2) = 2.
      PXYZ(3) = 2.
      NXYZ(1) = -1.
      NXYZ(2) = 1.
      NXYZ(3) = 0.5
      COLOUR(1) = 0.4
      COLOUR(2) = 0.2
      COLOUR(3) = 0.8
      call ns2vdisk(PXYZ, NXYZ, 0., 2., COLOUR)
c
c     native labels
      call ns2text(0., 0., 0.,    1., 0., 0.,   0., 1., 0.,
     +      0.2, 0.8, 0.7, 'README.TXT')
      PXYZ(1) = 0.
      PXYZ(2) = 2.
      PXYZ(3) = 0.
      RT(1) = 1.
      RT(2) = 0.
      RT(3) = 0.
      UP(1) = 0.
      UP(2) = 0.71
      UP(3) = 0.71
      COLOUR(1) = 0.7
      COLOUR(2) = 0.8
      COLOUR(3) = 0.2
      call ns2vtext(PXYZ, RT, UP, COLOUR, 'METOO.FITS')
c     
c     native points
      call ns2point(-3., -3., -3., 1., 0., 0.)
      PXYZ(1) = -3.
      PXYZ(2) = -3.
      PXYZ(3) = -3.5
      COLOUR(1) = 0.
      COLOUR(2) = 1.
      COLOUR(3) = 0.
      call ns2vpoint(PXYZ, COLOUR)
c
c     native thick points
      call ns2thpoint(-3., -3., -4., 1., 1., 1., 4.)
      PXYZ(1) = -3.
      PXYZ(2) = -3.
      PXYZ(3) = -4.5
      COLOUR(1) = 0.2
      COLOUR(2) = 0.5
      COLOUR(3) = 1.
      call ns2vthpoint(PXYZ, COLOUR, 8.)
c
c     native lines
      call ns2line(4., 4., -4., 5., 5., -4., 0.8, 0.2, 0.8)
      P1(1) = 4.
      P1(2) = 4.
      P1(3) = -4.
      P2(1) = 5.
      P2(2) = 5.
      P2(3) = -4.5
      COLOUR(1) = 0.8
      COLOUR(2) = 0.5
      COLOUR(3) = 0.8
      call ns2vline(P1, P2, COLOUR)
c
c     native thick lines
      call ns2thline(4., 4., -4.5, 5., 5., -4.5, 0.8, 0.2, 0.8, 3.0)
      P1(1) = 4.
      P1(2) = 4.
      P1(3) = -4.5
      P2(1) = 5.
      P2(2) = 5.
      P2(3) = -5.
      COLOUR(1) = 0.8
      COLOUR(2) = 0.5
      COLOUR(3) = 0.8
      call ns2vthline(P1, P2, COLOUR, 3.)
c
c     native color-blended lines
      call ns2cline(4., 4., -5.,    6., 6., -5., 
     +     .8, 0.2, 0.8,  0.2, 0.8, 0.2)
      P1(1) = 4.
      P1(2) = 4.
      P1(3) = -5.5
      P2(1) = 6.
      P2(2) = 6.
      P2(3) = -6.
      COL1(1) = 1.
      COL1(2) = 0.
      COL1(3) = 0.
      COL2(1) = 0.
      COL2(2) = 1.
      COL2(3) = 0.
      call ns2vcline(P1, P2, COL1, COL2)
c
c     3-vertex facets
      PF3(1,1) = -6.
      PF3(2,1) = -6.
      PF3(3,1) = 6.
c
      PF3(1,2) = -6.
      PF3(2,2) = -8.
      PF3(3,2) = 6.
c
      PF3(1,3) = -7.
      PF3(2,3) = -5.
      PF3(3,3) = 7.
c
      COLOUR(1) = 0.8
      COLOUR(2) = 0.4
      COLOUR(3) = 0.2
      call ns2vf3(PF3, COLOUR)
c
      PF3(1,1) = -9.
      PF3(2,1) = -6.
      PF3(3,1) = 6.
c
      PF3(1,2) = -9.
      PF3(2,2) = -8.
      PF3(3,2) = 6.
c
      PF3(1,3) = -9.
      PF3(2,3) = -5.
      PF3(3,3) = 7.
c
      COLS(1,1) = 1.
      COLS(2,1) = 0.
      COLS(3,1) = 0.
c
      COLS(1,2) = 0.
      COLS(2,2) = 1.
      COLS(3,2) = 0.
c
      COLS(1,3) = 0.
      COLS(2,3) = 0.
      COLS(3,3) = 1.
      call ns2vf3c(PF3, COLS)
c
      PF3(1,1) = -9.
      PF3(2,1) = -1.
      PF3(3,1) = 6.
c
      PF3(1,2) = -9.
      PF3(2,2) = -3.
      PF3(3,2) = 6.
c
      PF3(1,3) = -9.
      PF3(2,3) = 0.
      PF3(3,3) = 7.
c
      NORMS(1,1) = 1.
      NORMS(2,1) = 1.
      NORMS(3,1) = 0.
c
      NORMS(1,2) = 1.
      NORMS(2,2) = 0.
      NORMS(3,2) = 1.
c
      NORMS(1,3) = 0.
      NORMS(2,3) = 1.
      NORMS(3,3) = 1.
c
      COLOUR(1) = 0.
      COLOUR(2) = 1.
      COLOUR(3) = 0.
      call ns2vf3n(PF3, NORMS, COLOUR)
c
      PF3(1,1) = -9.
      PF3(2,1) = -7.
      PF3(3,1) = 4.
c
      PF3(1,2) = -9.
      PF3(2,2) = -11.
      PF3(3,2) = 6.
c
      PF3(1,3) = -7.
      PF3(2,3) = -5.
      PF3(3,3) = 7.
      call ns2vf3nc(PF3, NORMS, COLS)
c
c     4-vertex facets
c
      PF4(1,1) = 6.
      PF4(2,1) = 6.
      PF4(3,1) = 6.
c
      PF4(1,2) = 6.
      PF4(2,2) = 7.
      PF4(3,2) = 4.
c
      PF4(1,3) = 7.
      PF4(2,3) = 7.
      PF4(3,3) = 4.
c
      PF4(1,4) = 7.
      PF4(2,4) = 6.
      PF4(3,4) = 6.
      COLOUR(1) = 0.8
      COLOUR(2) = 0.4
      COLOUR(3) = 0.2
      call ns2vf4(PF4, COLOUR)
c
      PF4(1,1) = 6.
      PF4(2,1) = 6.
      PF4(3,1) = 7.
c
      PF4(1,2) = 6.
      PF4(2,2) = 7.
      PF4(3,2) = 7.
c
      PF4(1,3) = 7.
      PF4(2,3) = 7.
      PF4(3,3) = 8.
c
      PF4(1,4) = 7.
      PF4(2,4) = 6.
      PF4(3,4) = 8.
c
      COL4(1,1) = 1.
      COL4(2,1) = 1.
      COL4(3,1) = 0.
c
      COL4(1,2) = 0.
      COL4(2,2) = 1.
      COL4(3,2) = 1.
c
      COL4(1,3) = 1.
      COL4(2,3) = 0.
      COL4(3,3) = 1.
c
      COL4(1,4) = 0.5
      COL4(2,4) = 0.5
      COL4(3,4) = 0.5
      call ns2vf4c(PF4, COL4)
c
      PF4(1,1) = 6.
      PF4(2,1) = 6.
      PF4(3,1) = 9.
c
      PF4(1,2) = 6.
      PF4(2,2) = 5.
      PF4(3,2) = 9.
c
      PF4(1,3) = 5.
      PF4(2,3) = 5.
      PF4(3,3) = 9.
c
      PF4(1,4) = 5.
      PF4(2,4) = 6.
      PF4(3,4) = 9.
c
      NORM4(1,1) = 0.
      NORM4(2,1) = 0.
      NORM4(3,1) = 1.
c
      NORM4(1,2) = 0.
      NORM4(2,2) = 1.
      NORM4(3,2) = 1.
c
      NORM4(1,3) = 1.
      NORM4(2,3) = 0.
      NORM4(3,3) = 1.
c
      NORM4(1,4) = 1.
      NORM4(2,4) = 1.
      NORM4(3,4) = 1.
      COLOUR(1) = 0.
      COLOUR(2) = 1.
      COLOUR(3) = 1.
      call ns2vf4n(PF4, NORM4, COLOUR)
c
c     ns2vf4nc UNTESTED
c
c
c
c     textured 4-vertex facet
      PF4(1,1) = 3.
      PF4(2,1) = -3.
      PF4(3,1) = -8.
c
      PF4(1,2) = 5.
      PF4(2,2) = -3.
      PF4(3,2) = -8.
c
      PF4(1,3) = 5.
      PF4(2,3) = -5.
      PF4(3,3) = -9.
c
      PF4(1,4) = 3.
      PF4(2,4) = -5.
      PF4(3,4) = -9.
      COLOUR(1) = 1.
      COLOUR(2) = 1.
      COLOUR(3) = 1.
      call ns2vf4t(PF4, COLOUR, 'strongbluemarble_pow2_rgb.tga', 
     +      1.0, 'o')
c
c
c     two lights
      call ns2i(4., -4., -11., 0.7, 0.7, 1.)
      PXYZ(1) = -4.
      PXYZ(2) = 4.
      PXYZ(3) = 11.
      COLOUR(1) = 1.
      COLOUR(2) = 1.
      COLOUR(3) = 1.
      call ns2vi(PXYZ, COLOUR)
c
c     native markers
      call ns2m(0, 1., 4., 8., -1.5, 0.6, 0.2, 0.3)
      call ns2m(1, 2., 4., 8., -3., 0.6, 0.3, 0.2)
      PXYZ(1) = 4.
      PXYZ(2) = 8.
      PXYZ(3) = -4.5
      COLOUR(1) = 0.2
      COLOUR(2) = 0.6
      COLOUR(3) = 0.3
      call ns2vm(2, 0.8, PXYZ, COLOUR)
      PXYZ(3) = -6.
      call ns2vm(3, 1.6, PXYZ, COLOUR)
c
c     Go into S2PLOT interactive mode
      call s2show(1)
c     
      end
