! fs2uc7.f90: demonstration / use case 7 for S2PLOT library.
!
! David Barnes, February 2006
!
! $Id: fs2uc7.f90,v 3.3 2007/04/04 23:07:00 dbarnes Exp $
!
! Demonstrates drawing coordinate box, plotting coloured parametric
! functinos, various point symbols, and disks, circles and arrows,
! drawn in different colours and thicknesses, from a FORTRAN driver
! program.
!
! NOTE: this file contains the "main program" for fs2uc7.  The next to 
! last thing the program does is to register a callback function with 
! the S2PLOT library.  This callback function (like all S2PLOT callback
! functions used from FORTRAN) *must* be external to this source file,
! and is declared so in the initial block of code just below.  The 
! source code for the 'NEWCALLBACK' function resides separately in a 
! second source file.
!
! The function NEWCALLBACK *itself* includes a further call to S2PLOT
! which registers another function for use by S2PLOT, viz. the call 
! to s2funxyr.  The same rule applies, and so that callback ('WAVE')
! is declared external to that source code file and defined in a third
! source file.
!
! All three files can be compiled together.  The EXTERNAL declarations
! simply (seem to) make the symbols exist in the final compiled binary.
! If all functions are provided in this (one) source file and are not
! EXTERNAL, the code will compile, but will generate segmentation 
! violations or illegal instruction calls when executed.
!
      INCLUDE 'fs2uc7.inc'
!
!     vectors for setting camera position...
      REAL*8 POSXYZ(3)
      REAL*8 UPVXYZ(3)
      REAL*8 DIRXYZ(3)
!     
!     Functions to be used by S2PLOT functions like s2funtc etc., MUST
!     be externally defined for FORTRAN compilations.
      EXTERNAL NEWCALLBACK
!     
!     Open the S2PLOT device, in mono and fullscreen mode
      call s2opend('/?')
!
!     Install a very nice colormap
      call s2icm('astro', 1000, 1400)
      call s2scir(1000, 1400)
!     
!     Set the S2PLOT world coordinate range
      call s2sci(1)
      call s2swin(-XLIMIT, XLIMIT, -YLIMIT, YLIMIT, -2., 2.)
      call s2box('BCDETSMNQ', 0., 0, 'BCDETSMNQ', 0., 0, &
           'BCDETSMNQ', 0., 0)
      call s2lab('x', 'y', 'f(x,y,t)', 's2funxy used to plot a surface')
      call s2wedge('Jy', 0.03, 0.06, 0.03, 0.41, -2.0, 2.0, 1)
!
!     Install the callback function to plot the dynamic surface geometry
      call cs2scb(NEWCALLBACK)
!
!     Flush graphics and enter interactive mode - never timeout (-1)
      call s2disp(-1, 1);
!
!     Report we are back in "main" program
      write (*, *) 'Control returned to main program ... re-show'
!
!     Add a red grid and redisplay with 10-second timeout
      call s2eras()
      call s2sci(2)
      call s2box('BCDEG', 0., 0, 'BCDEG', 0., 0, 'BCDEG', 0., 0)
      call s2disp(10, 0)
!
!     Change the colourmap and redisplay with 10-second timeout
      call s2icm('rainbow', 1401, 1800)
      call s2scir(1401, 1800)
!     
!     And set the camera position ...
      POSXYZ(1) = 5.
      POSXYZ(2) = 5.
      POSXYZ(3) = 5.
      UPVXYZ(1) = 5.
      UPVXYZ(2) = 5.
      UPVXYZ(3) = -5.
      DIRXYZ(1) = -1.
      DIRXYZ(2) = -1.
      DIRXYZ(3) = -1.
      call ss2sc(POSXYZ, UPVXYZ, DIRXYZ, 1)
      call ss2sas(0)
      call s2disp(10, 0)
!     
      end
