/* s2uc11.c: demonstration / use case 11 for S2PLOT library.
 *
 * David Barnes, October 2006
 *
 * $Id: s2uc11.c,v 1.2 2006/12/22 03:33:25 dbarnes Exp $
 *
 * Demonstrates display of a nice parametric surface function using
 * s2funuv.  Press 'r' once to get specular highlights on the surface.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "s2plot.h"

#define LIMIT 0.7
#define pi 3.14159265359

/* from StdParamSurfs.pdf */
/* amplitude, number of twists, major radius, minor radius */
#define AMP 0.4
#define NTW 1.5
#define R1 2.0
#define R2 0.5
inline float tkx(float *u, float *v) {
  return R2 * cos(*v) * cos(*u) + R1 * cos(*u) * (1. + AMP * cos(*u * NTW));
}
inline float tky(float *u, float *v) {
  return R2 * sin(*v) + AMP * sin(*u * NTW);
}
inline float tkz(float *u, float *v) {
  return R2 * cos(*v) * sin(*u) + R1 * sin(*u) * (1. + AMP * cos(*u * NTW));
}
inline float fcol(float *u, float *v) {
  return 0.5 + sin(0.5 * *u) * AMP * sin(*v);
}

int main(int argc, char **argv) {

  float x1 = -LIMIT, x2 = LIMIT; /* x world coord range */
  float y1 = -LIMIT, y2 = LIMIT; /* y world coord range */
  float z1 = -LIMIT, z2 = LIMIT; /* z world coord range */

  /* open S2PLOT device */
  if (!s2opend("/?", argc, argv)) {
    fprintf(stderr, "Failed to open S2PLOT device - exiting!\n");
    exit(-1);
  }

  /* set world coordinate range */
  s2swin(x1, x2, y1, y2, z1, z2);

  /* install a nice colourmap */
  s2icm("rainbow", 100, 500);
  s2scir(100, 500);

  /* call the parametric surface function */
  s2funuv(tkx, tky, tkz, fcol, 0., 4.*pi, 320, 0., 2.*pi, 90);

  /* flush graphics and enter interactive mode */
  s2show(1);

  /* successful run */
  return 0;

}

