/* s2uc12.c: demonstration / use case 12 for S2PLOT library.
 *
 * David Barnes, October 2006
 *
 * $Id: s2uc12.c,v 1.3 2007/04/04 22:55:26 dbarnes Exp $
 *
 * Demonstrate use of s2latexture to simply generate a texture with
 * LaTeX output on it for use in geometry.
 * 
 * Provide some LaTeX math in single quotes on the command line to 
 * see it texturised.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "s2plot.h"

int main(int argc, char **argv) {

  if (argc != 2) {
    fprintf(stderr, "usage: %s \"latex commands\"\n", argv[0]);
    fprintf(stderr, "eg: %s '$x \\cdot \\sqrt{3y} \\over \\left(y + i\\right)^n$'\n", argv[0]);
    exit(-1);
  }

  /* open S2PLOT device */
  if (!s2opend("/?", argc, argv)) {
    fprintf(stderr, "Failed to open S2PLOT device - exiting!\n");
    exit(-1);
  }

  /* set up coordinate system */
  s2svp(-0.7, 0.7, -0.7, 0.7, -0.7, 0.7);
  s2swin(-1., 1., -1., 1., -1., 1.);
  char *opt = "BCDETS";

  float aspect;
  int texnum = s2latexture(argv[1], &aspect);
  
  XYZ p[4];
  p[0].x = -0.3 * aspect; p[0].y =  0.3; p[0].z = 0.0;
  p[1].x =  0.3 * aspect; p[1].y =  0.3; p[1].z = 0.0;
  p[2].x =  0.3 * aspect; p[2].y = -0.3; p[2].z = 0.0;
  p[3].x = -0.3 * aspect; p[3].y = -0.3; p[3].z = 0.0;
  COLOUR col;
  col.r = col.g = col.b = 0.6;
  ns2vf4x(p, col, texnum, 1., 'o');
  
  /* draw and label a box around the points, in a non-green-ish colour */
  s2sci(S2_PG_RED);
  s2sch(1.2);
  s2slw(1);
  s2box(opt, 0.0, 0, opt, 0.0, 0, opt, 0.0, 0);

  /* show the environment */
  s2show(1);

  return (0);
}
