/* s2uc8.c: sample code 9 for S2PLOT library
 *
 * David Barnes, February 2006
 *
 * $Id: s2uc9.c,v 3.5 2007/04/04 23:07:00 dbarnes Exp $
 *
 * This code produces a chromastereoscopic display of points
 * in a normal flat projection.  It's really rather cool.  The points
 * change colour depending on proximity to camera.  You'll need
 * chromastereo glasses to "maximise" the depth effect/perception.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>
#include "s2plot.h"

#define NPOINTS 500
#define RANDSEED 103491794l

void ptcb(double *time, int *keycount);

int main(int argc, char **argv) {

  /* open S2PLOT device */
  if (!s2opend("/S2MONOF", argc, argv)) {
    fprintf(stderr, "Failed to open S2PLOT device - exiting!\n");
    exit(-1);
  }
  s2swin(-1.,1.,-1.,1.,-1.,1.);

  int i = ss2lcm("chromapal.txt", 100, 2000);
  s2scir(100, 100+i-1);

  cs2scb(ptcb);

  s2show(1);

  return 0;
}


void ptcb(double *time, int *keycount) {
  static int beenhere = 0;
  static float *xpts, *ypts, *zpts;
  static float *dist, *size;
  static int np = NPOINTS;
  int i;

  if (!beenhere) {
    float x1, x2, y1, y2, z1, z2;
    s2qwin(&x1, &x2, &y1, &y2, &z1, &z2);
    /* generate a set of points extending over world coordinate space */
    xpts = (float *)calloc(np, sizeof(float));
    ypts = (float *)calloc(np, sizeof(float));
    zpts = (float *)calloc(np, sizeof(float));
    dist = (float *)calloc(np, sizeof(float));
    size = (float *)calloc(np, sizeof(float));
    srand(RANDSEED);
    for (i = 0; i < np; i++) {
      xpts[i] = x1 + (float)(rand()) / (float)RAND_MAX * (x2 - x1);
      ypts[i] = y1 + (float)(rand()) / (float)RAND_MAX * (y2 - y1);
      zpts[i] = z1 + (float)(rand()) / (float)RAND_MAX * (z2 - z1);
    }
    beenhere = 1;
  }

  /* figure out distance and sizes */
  XYZ pos, up, vdir;
  ss2qc(&pos, &up, &vdir, 1);
  float dmin = 9e30;
  float dmax = -9e30;
  for (i = 0; i < np; i++) {
    dist[i] = sqrt((xpts[i] - pos.x) * (xpts[i] - pos.x) +
		   (ypts[i] - pos.y) * (ypts[i] - pos.y) +
		   (zpts[i] - pos.z) * (zpts[i] - pos.z));
    if (dist[i] < dmin) {
      dmin = dist[i];
    }
    if (dist[i] > dmax) {
      dmax = dist[i];
    }
  }
  for (i = 0; i < np; i++) {
    size[i] = 8.0 - (dist[i] - dmin) / (dmax - dmin) * 6.0;
  }
  /*
  s2sci(S2_PG_LTGREY);
  for (i = 0; i < np; i++) {
    s2slw(size[i]-2);
    s2pt1(xpts[i], ypts[i], zpts[i], 1);
  }
  */
  s2chromacpts(np, xpts, ypts, zpts, dist, size, dmin, dmax);
  
}
